Reference Implementation
========================

The RecipeMD reference implementation is provided as a Python package. The package contains the command line tools
:ref:`cli_recipemd` and :ref:`cli_recipemd_find`. It can also be used as a library. The python api is documented in
:doc:`_apidoc/recipemd`.


.. toctree::
   :maxdepth: 1

   install
   cli
   changelog
   API Documentation <_apidoc/recipemd>